Class: MtgCardMaker::SpriteSheetAssets
- Inherits:
-
Object
- Object
- MtgCardMaker::SpriteSheetAssets
- Defined in:
- lib/mtg_card_maker/sprite_sheet_assets.rb
Overview
Handles the creation of shared assets (fonts, gradients, masks) for sprite sheets
Instance Method Summary collapse
-
#add_assets_to_sprite(xml) ⇒ Object
Add all shared assets to the sprite sheet XML.
-
#initialize ⇒ SpriteSheetAssets
constructor
A new instance of SpriteSheetAssets.
Constructor Details
#initialize ⇒ SpriteSheetAssets
Returns a new instance of SpriteSheetAssets.
6 7 8 |
# File 'lib/mtg_card_maker/sprite_sheet_assets.rb', line 6 def initialize @color_schemes = build_color_schemes end |
Instance Method Details
#add_assets_to_sprite(xml) ⇒ Object
Add all shared assets to the sprite sheet XML
11 12 13 14 15 |
# File 'lib/mtg_card_maker/sprite_sheet_assets.rb', line 11 def add_assets_to_sprite(xml) add_sprite_styles(xml) add_sprite_masks(xml) add_sprite_gradients(xml) end |